@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package IPC::Open3::Callback::CommandRunner;
-$IPC::Open3::Callback::CommandRunner::VERSION = '1.15';
+$IPC::Open3::Callback::CommandRunner::VERSION = '1.16';
 # ABSTRACT: A utility class that wraps IPC::Open3::Callback with available output buffers and an option to die on failure instead of returning exit code.
 
 use Hash::Util qw(lock_keys);
@@ -101,8 +101,8 @@ sub run_or_die {
     if ($exit_code) {
         my $exception = IPC::Open3::Callback::CommandFailedException->new(
             \@command, $exit_code,
-            $self->get_out_buffer(),
-            $self->get_err_buffer()
+            scalar( $self->get_out_buffer() ),
+            scalar( $self->get_err_buffer() )
         );
         die($exception);
     }
@@ -122,7 +122,7 @@ IPC::Open3::Callback::CommandRunner - A utility class that wraps IPC::Open3::Cal
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =head1 SYNOPSIS
 
